@@ -1,12 +1,16 @@
-from strictdoc.backend.dsl.models.document import Document
-from strictdoc.backend.dsl.models.inline_link import InlineLink
-from strictdoc.backend.dsl.models.requirement import (
+from typing import Optional
+
+from strictdoc.backend.sdoc.models.document import Document
+from strictdoc.backend.sdoc.models.inline_link import InlineLink
+from strictdoc.backend.sdoc.models.requirement import (
     Requirement,
     RequirementComment,
 )
-from strictdoc.backend.dsl.models.section import FreeText
+from strictdoc.backend.sdoc.models.section import FreeText
 from strictdoc.core.traceability_index import TraceabilityIndex
-from strictdoc.export.html.document_type import DocumentType
+from strictdoc.export.html.renderers.html_fragment_writer import (
+    HTMLFragmentWriter,
+)
 from strictdoc.export.html.renderers.link_renderer import LinkRenderer
 from strictdoc.export.html.renderers.text_to_html_writer import TextToHtmlWriter
 from strictdoc.export.rst.rst_to_html_fragment_writer import (
@@ -20,12 +24,14 @@ class MarkupRenderer:
         markup,
         traceability_index: TraceabilityIndex,
         link_renderer: LinkRenderer,
-        context_document: Document,
-        document_type: DocumentType,
+        context_document: Optional[Document],
     ):
-        assert isinstance(document_type, DocumentType)
+        assert isinstance(traceability_index, TraceabilityIndex)
+        assert isinstance(link_renderer, LinkRenderer)
         if not markup or markup == "RST":
             html_fragment_writer = RstToHtmlFragmentWriter
+        elif markup == "HTML":
+            html_fragment_writer = HTMLFragmentWriter
         else:
             html_fragment_writer = TextToHtmlWriter
         return MarkupRenderer(
@@ -33,7 +39,6 @@ class MarkupRenderer:
             traceability_index,
             link_renderer,
             context_document,
-            document_type,
         )
 
     def __init__(
@@ -41,16 +46,12 @@ class MarkupRenderer:
         fragment_writer,
         traceability_index: TraceabilityIndex,
         link_renderer: LinkRenderer,
-        context_document: Document,
-        document_type: DocumentType,
+        context_document: Optional[Document],
     ):
-        assert isinstance(document_type, DocumentType)
-
         self.fragment_writer = fragment_writer
         self.traceability_index = traceability_index
         self.link_renderer: LinkRenderer = link_renderer
         self.context_document: Document = context_document
-        self.document_type = document_type
 
         self.cache = {}
         self.rationale_cache = {}
@@ -59,7 +60,6 @@ class MarkupRenderer:
         assert isinstance(requirement, Requirement)
         if requirement in self.cache:
             return self.cache[requirement]
-
         output = self.fragment_writer.write(
             requirement.get_statement_single_or_multiline()
         )
@@ -89,9 +89,9 @@ class MarkupRenderer:
 
         return output
 
-    def render_free_text(self, free_text):
+    def render_free_text(self, document_type, free_text):
         assert isinstance(free_text, FreeText)
-        if free_text in self.cache:
+        if (document_type, free_text) in self.cache:
             return self.cache[free_text]
 
         parts_output = ""
@@ -101,12 +101,12 @@ class MarkupRenderer:
             elif isinstance(part, InlineLink):
                 node = self.traceability_index.get_node_by_uid(part.link)
                 href = self.link_renderer.render_requirement_link(
-                    node, self.context_document, self.document_type
+                    node, self.context_document, document_type
                 )
                 parts_output += self.fragment_writer.write_link(
                     node.title, href
                 )
         output = self.fragment_writer.write(parts_output)
-        self.cache[free_text] = output
+        self.cache[(document_type, free_text)] = output
 
         return output
